=== modified file 'Makefile'
--- Makefile	2007-08-14 02:48:36 +0000
+++ Makefile	2007-08-14 03:59:22 +0000
@@ -67,6 +67,13 @@
 
 ### Documentation ###
 
+# set PRETTY to get docs that look like the Bazaar web site
+ifdef PRETTY
+rst2html := python tools/rst2prettyhtml.py doc/bazaar-vcs.org.kid 
+else
+rst2html := python tools/rst2html.py --link-stylesheet --footnote-references=superscript 
+endif
+
 # translate txt docs to html
 derived_txt_files := \
 	doc/en/user-reference/bzr_man.txt \
@@ -76,18 +83,21 @@
 txt_files := $(wildcard $(addsuffix /*.txt, $(doc_dir))) $(derived_txt_files) \
 	doc/en/mini-tutorial/index.txt \
 	doc/index.txt
+non_txt_files := \
+       doc/default.css \
+       doc/en/quick-reference/quick-start-summary.svg
 htm_files := $(patsubst %.txt, %.html, $(txt_files)) 
 dev_txt_files := $(wildcard $(addsuffix /*.txt, doc/developers))
 dev_htm_files := $(patsubst %.txt, %.html, $(dev_txt_files)) 
 
 doc/developers/%.html: doc/developers/%.txt
-	python tools/rst2html.py --link-stylesheet --stylesheet=../default.css --footnote-references=superscript $< $@
+	$(rst2html) --stylesheet=../default.css $< $@
 
 doc/index.html: doc/index.txt
-	python tools/rst2html.py --link-stylesheet --stylesheet=default.css --footnote-references=superscript $< $@
+	$(rst2html) --stylesheet=default.css $< $@
 
 %.html: %.txt
-	python tools/rst2html.py --link-stylesheet --stylesheet=../../default.css --footnote-references=superscript $< $@
+	$(rst2html) --stylesheet=../../default.css $< $@
 
 MAN_DEPENDENCIES = bzrlib/builtins.py \
 		 bzrlib/bundle/commands.py \
@@ -111,43 +121,27 @@
 man1/bzr.1: $(MAN_DEPENDENCIES)
 	python generate_docs.py -o $@ man
 
-WEB_DOCS = $(htm_files) $(dev_htm_files) \
-	   doc/default.css \
-	   doc/en/quick-reference/quick-start-summary.svg \
-	   doc/developers/performance.png
-ALL_DOCS = $(WEB_DOCS) $(MAN_PAGES)
-docs: $(ALL_DOCS)
-
 # build a png of our performance task list
 doc/developers/performance.png: doc/developers/performance.dot
 	@echo Generating $@
 	@dot -Tpng $< -o$@ || echo "Dot not installed; skipping generation of $@"
 
-
-### Pretty Documentation ###
-
+derived_web_docs = $(htm_files) $(dev_htm_files) doc/developers/performance.png
+WEB_DOCS = $(derived_web_docs) $(non_txt_files)
+ALL_DOCS = $(derived_web_docs) $(MAN_PAGES)
+
+# the main target to build all the docs
+docs: $(ALL_DOCS)
+
+# produce a tree containing just the final docs, ready for uploading to the web
 HTMLDIR := html_docs
-PRETTYDIR := pretty_docs
-
-# Produce HTML docs to upload on Canonical server
 html-docs: docs
 	python tools/win32/ostools.py copytree $(WEB_DOCS) $(HTMLDIR)
 
-$(PRETTYDIR)/%.html: pretty_docs doc/%.txt
-	python tools/rst2prettyhtml.py doc/bazaar-vcs.org.kid doc/$*.txt \
-	$(PRETTYDIR)/$*.html
-
-pretty-html-docs: pretty_files
-
-pretty_docs:
-	python -c "import os; os.mkdir('$(PRETTYDIR)')"
-
-pretty_files: $(patsubst doc/%.txt, $(PRETTYDIR)/%.html, $(txt_files))
-
 # clean produced docs
 clean-docs:
 	python tools/win32/ostools.py remove $(ALL_DOCS) \
-	$(HTMLDIR) $(PRETTYDIR) $(derived_txt_files)
+	$(HTMLDIR) $(derived_txt_files)
 
 
 ### Windows Support ###

=== modified file 'doc/bazaar-vcs.org.kid'
--- doc/bazaar-vcs.org.kid	2006-11-10 02:34:00 +0000
+++ doc/bazaar-vcs.org.kid	2007-08-14 03:59:22 +0000
@@ -181,8 +181,7 @@
 <div id="username" class="vnav">
 <h4>Website Links</h4>
 <ul>
-<li><a href="index.htm">Documentation index</a></li>
-<li><a href="http://doc.bazaar-vcs.org">Other versions</a></li>
+<li><a href="http://doc.bazaar-vcs.org">Documentation</a></li>
 <li><a href="http://bazaar-vcs.org">Wiki</a></li>
 </ul>
 </div>

=== modified file 'tools/rst2prettyhtml.py'
--- tools/rst2prettyhtml.py	2007-07-17 13:47:45 +0000
+++ tools/rst2prettyhtml.py	2007-08-14 03:59:22 +0000
@@ -66,5 +66,6 @@
 
 assert len(sys.argv) > 1
 
-main(*sys.argv[1:])
-
+# Strip options so only the arguments are passed
+args = [x for x in sys.argv[1:] if not x.startswith('-')]
+main(*args)

